@@ -1,6 +1,6 @@
 """
 The :mod:`pysad.transform.ensemble` module consist of ensemblers to combine scores from multiple anomaly detectors.
 """
-from .ensemblers import MaximumScoreEnsembler,AverageScoreEnsembler,MedianScoreEnsembler, PYODScoreEnsembler, AverageOfMaximumScoreEnsembler, MaximumOfAverageScoreEnsembler
+from .ensemblers import MaximumScoreEnsembler, AverageScoreEnsembler, MedianScoreEnsembler, AverageOfMaximumScoreEnsembler, MaximumOfAverageScoreEnsembler
 
 __all__ = ["MaximumScoreEnsembler", "MedianScoreEnsembler", "AverageScoreEnsembler", "MaximumOfAverageScoreEnsembler", "AverageOfMaximumScoreEnsembler"]
